from google.protobuf import any_pb2 as _any_pb2
import connector_pb2 as _connector_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Metric(_message.Message):
    __slots__ = ["key", "name", "created_at", "updated_at", "custom", "value_type", "config", "connector", "connected_metrics"]
    class ValueType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        VALUE_TYPE_UNKNOWN: _ClassVar[Metric.ValueType]
        VALUE_TYPE_INTEGER: _ClassVar[Metric.ValueType]
        VALUE_TYPE_FLOAT: _ClassVar[Metric.ValueType]
        VALUE_TYPE_STRING: _ClassVar[Metric.ValueType]
        VALUE_TYPE_DATE: _ClassVar[Metric.ValueType]
        VALUE_TYPE_BOOLEAN: _ClassVar[Metric.ValueType]
    VALUE_TYPE_UNKNOWN: Metric.ValueType
    VALUE_TYPE_INTEGER: Metric.ValueType
    VALUE_TYPE_FLOAT: Metric.ValueType
    VALUE_TYPE_STRING: Metric.ValueType
    VALUE_TYPE_DATE: Metric.ValueType
    VALUE_TYPE_BOOLEAN: Metric.ValueType
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_METRICS_FIELD_NUMBER: _ClassVar[int]
    key: str
    name: str
    created_at: str
    updated_at: str
    custom: bool
    value_type: Metric.ValueType
    config: _any_pb2.Any
    connector: _connector_pb2.Connector
    connected_metrics: _containers.RepeatedCompositeFieldContainer[Metric]
    def __init__(self, key: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., custom: bool = ..., value_type: _Optional[_Union[Metric.ValueType, str]] = ..., config: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., connector: _Optional[_Union[_connector_pb2.Connector, _Mapping]] = ..., connected_metrics: _Optional[_Iterable[_Union[Metric, _Mapping]]] = ...) -> None: ...

class MetricsRequest(_message.Message):
    __slots__ = ["company_id", "connection"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    connection: str
    def __init__(self, company_id: _Optional[str] = ..., connection: _Optional[str] = ...) -> None: ...

class MetricsResponse(_message.Message):
    __slots__ = ["metrics"]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[Metric]
    def __init__(self, metrics: _Optional[_Iterable[_Union[Metric, _Mapping]]] = ...) -> None: ...

class MetricRequest(_message.Message):
    __slots__ = ["company_id", "key"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    key: str
    def __init__(self, company_id: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class MetricResponse(_message.Message):
    __slots__ = ["metric", "options"]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    metric: Metric
    options: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, metric: _Optional[_Union[Metric, _Mapping]] = ..., options: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
import service_pb2 as _service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Connector(_message.Message):
    __slots__ = ["key", "name", "created_at", "updated_at", "service", "config"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    key: str
    name: str
    created_at: str
    updated_at: str
    service: _service_pb2.Service
    config: _any_pb2.Any
    def __init__(self, key: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., service: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., config: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class DispatcherRequest(_message.Message):
    __slots__ = ["chart_dispatcher_uuid"]
    CHART_DISPATCHER_UUID_FIELD_NUMBER: _ClassVar[int]
    chart_dispatcher_uuid: str
    def __init__(self, chart_dispatcher_uuid: _Optional[str] = ...) -> None: ...

class DispatcherResponse(_message.Message):
    __slots__ = ["success", "cached", "payload"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CACHED_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    success: bool
    cached: bool
    payload: _any_pb2.Any
    def __init__(self, success: bool = ..., cached: bool = ..., payload: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ConnectorsRequest(_message.Message):
    __slots__ = ["company_id"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    def __init__(self, company_id: _Optional[str] = ...) -> None: ...

class ConnectorsResponse(_message.Message):
    __slots__ = ["connectors"]
    CONNECTORS_FIELD_NUMBER: _ClassVar[int]
    connectors: _containers.RepeatedCompositeFieldContainer[Connector]
    def __init__(self, connectors: _Optional[_Iterable[_Union[Connector, _Mapping]]] = ...) -> None: ...

class ConnectorRequest(_message.Message):
    __slots__ = ["company_id", "key"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    key: str
    def __init__(self, company_id: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class ConnectorResponse(_message.Message):
    __slots__ = ["connectors"]
    CONNECTORS_FIELD_NUMBER: _ClassVar[int]
    connectors: Connector
    def __init__(self, connectors: _Optional[_Union[Connector, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import connector_pb2 as connector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmetric.proto\x12\x10\x63onnector.metric\x1a\x19google/protobuf/any.proto\x1a\x0f\x63onnector.proto\"\xf0\x03\n\x06Metric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x05 \x01(\x08\x12;\n\nvalue_type\x18\x06 \x01(\x0e\x32\".connector.metric.Metric.ValueTypeH\x00\x88\x01\x01\x12)\n\x06\x63onfig\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x12\x36\n\tconnector\x18\x08 \x01(\x0b\x32\x1e.connector.connector.ConnectorH\x02\x88\x01\x01\x12\x33\n\x11\x63onnected_metrics\x18\t \x03(\x0b\x32\x18.connector.metric.Metric\"\x95\x01\n\tValueType\x12\x16\n\x12VALUE_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12VALUE_TYPE_INTEGER\x10\x01\x12\x14\n\x10VALUE_TYPE_FLOAT\x10\x02\x12\x15\n\x11VALUE_TYPE_STRING\x10\x03\x12\x13\n\x0fVALUE_TYPE_DATE\x10\x04\x12\x16\n\x12VALUE_TYPE_BOOLEAN\x10\x05\x42\r\n\x0b_value_typeB\t\n\x07_configB\x0c\n\n_connector\"L\n\x0eMetricsRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x17\n\nconnection\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_connection\"<\n\x0fMetricsResponse\x12)\n\x07metrics\x18\x01 \x03(\x0b\x32\x18.connector.metric.Metric\"0\n\rMetricRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"K\n\x0eMetricResponse\x12(\n\x06metric\x18\x01 \x01(\x0b\x32\x18.connector.metric.Metric\x12\x0f\n\x07options\x18\x02 \x03(\t2\xac\x01\n\rMetricService\x12N\n\x07Metrics\x12 .connector.metric.MetricsRequest\x1a!.connector.metric.MetricsResponse\x12K\n\x06Metric\x12\x1f.connector.metric.MetricRequest\x1a .connector.metric.MetricResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METRIC']._serialized_start=79
  _globals['_METRIC']._serialized_end=575
  _globals['_METRIC_VALUETYPE']._serialized_start=386
  _globals['_METRIC_VALUETYPE']._serialized_end=535
  _globals['_METRICSREQUEST']._serialized_start=577
  _globals['_METRICSREQUEST']._serialized_end=653
  _globals['_METRICSRESPONSE']._serialized_start=655
  _globals['_METRICSRESPONSE']._serialized_end=715
  _globals['_METRICREQUEST']._serialized_start=717
  _globals['_METRICREQUEST']._serialized_end=765
  _globals['_METRICRESPONSE']._serialized_start=767
  _globals['_METRICRESPONSE']._serialized_end=842
  _globals['_METRICSERVICE']._serialized_start=845
  _globals['_METRICSERVICE']._serialized_end=1017
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ATS: _ClassVar[TypeEnum]
    CHANNEL: _ClassVar[TypeEnum]
    INTEGRATION: _ClassVar[TypeEnum]

class OperationEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    GET: _ClassVar[OperationEnum]
    CREATE: _ClassVar[OperationEnum]
    READ: _ClassVar[OperationEnum]
    UPDATE: _ClassVar[OperationEnum]
    DELETE: _ClassVar[OperationEnum]
ATS: TypeEnum
CHANNEL: TypeEnum
INTEGRATION: TypeEnum
GET: OperationEnum
CREATE: OperationEnum
READ: OperationEnum
UPDATE: OperationEnum
DELETE: OperationEnum

class PortalGetRequest(_message.Message):
    __slots__ = ["uuid"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    def __init__(self, uuid: _Optional[str] = ...) -> None: ...

class PortalReadRequest(_message.Message):
    __slots__ = ["company_uuid"]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    company_uuid: str
    def __init__(self, company_uuid: _Optional[str] = ...) -> None: ...

class PortalDeleteRequest(_message.Message):
    __slots__ = ["uuid"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    def __init__(self, uuid: _Optional[str] = ...) -> None: ...

class PortalCreateRequest(_message.Message):
    __slots__ = ["company_uuid", "name", "type", "className", "configuration"]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CLASSNAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    company_uuid: str
    name: str
    type: TypeEnum
    className: str
    configuration: _any_pb2.Any
    def __init__(self, company_uuid: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[_Union[TypeEnum, str]] = ..., className: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class PortalUpdateRequest(_message.Message):
    __slots__ = ["uuid", "name", "configuration"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    name: str
    configuration: _any_pb2.Any
    def __init__(self, uuid: _Optional[str] = ..., name: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class PortalResponse(_message.Message):
    __slots__ = ["operation", "success", "uuid", "name", "type", "key", "className", "configuration", "created_at", "updated_at"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    CLASSNAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    uuid: str
    name: str
    type: TypeEnum
    key: str
    className: str
    configuration: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., uuid: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[_Union[TypeEnum, str]] = ..., key: _Optional[str] = ..., className: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class PortalsResponse(_message.Message):
    __slots__ = ["operation", "success", "portals"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    PORTALS_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    portals: _containers.RepeatedCompositeFieldContainer[PortalResponse]
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., portals: _Optional[_Iterable[_Union[PortalResponse, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x11\x63onnector.service\x1a\x19google/protobuf/any.proto\"\xcc\x02\n\x07Service\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\x12\x34\n\x04type\x18\x05 \x01(\x0e\x32&.connector.service.Service.ServiceType\x12\x0c\n\x04icon\x18\x06 \x01(\t\x12\x30\n\reditor_config\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x88\x01\x01\"v\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10SERVICE_TYPE_ATS\x10\x01\x12\x18\n\x14SERVICE_TYPE_CHANNEL\x10\x02\x12\x19\n\x15SERVICE_TYPE_PLATFORM\x10\x03\x42\x10\n\x0e_editor_config\"%\n\x0fServicesRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\"@\n\x10ServicesResponse\x12,\n\x08services\x18\x01 \x03(\x0b\x32\x1a.connector.service.Service\"1\n\x0eServiceRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\">\n\x0fServiceResponse\x12+\n\x07service\x18\x01 \x01(\x0b\x32\x1a.connector.service.Service2\xb9\x01\n\x10\x43onnectorService\x12S\n\x08Services\x12\".connector.service.ServicesRequest\x1a#.connector.service.ServicesResponse\x12P\n\x07Service\x12!.connector.service.ServiceRequest\x1a\".connector.service.ServiceResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVICE']._serialized_start=64
  _globals['_SERVICE']._serialized_end=396
  _globals['_SERVICE_SERVICETYPE']._serialized_start=260
  _globals['_SERVICE_SERVICETYPE']._serialized_end=378
  _globals['_SERVICESREQUEST']._serialized_start=398
  _globals['_SERVICESREQUEST']._serialized_end=435
  _globals['_SERVICESRESPONSE']._serialized_start=437
  _globals['_SERVICESRESPONSE']._serialized_end=501
  _globals['_SERVICEREQUEST']._serialized_start=503
  _globals['_SERVICEREQUEST']._serialized_end=552
  _globals['_SERVICERESPONSE']._serialized_start=554
  _globals['_SERVICERESPONSE']._serialized_end=616
  _globals['_CONNECTORSERVICE']._serialized_start=619
  _globals['_CONNECTORSERVICE']._serialized_end=804
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Service(_message.Message):
    __slots__ = ["key", "name", "created_at", "updated_at", "type", "icon", "editor_config"]
    class ServiceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        SERVICE_TYPE_UNSPECIFIED: _ClassVar[Service.ServiceType]
        SERVICE_TYPE_ATS: _ClassVar[Service.ServiceType]
        SERVICE_TYPE_CHANNEL: _ClassVar[Service.ServiceType]
        SERVICE_TYPE_PLATFORM: _ClassVar[Service.ServiceType]
    SERVICE_TYPE_UNSPECIFIED: Service.ServiceType
    SERVICE_TYPE_ATS: Service.ServiceType
    SERVICE_TYPE_CHANNEL: Service.ServiceType
    SERVICE_TYPE_PLATFORM: Service.ServiceType
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ICON_FIELD_NUMBER: _ClassVar[int]
    EDITOR_CONFIG_FIELD_NUMBER: _ClassVar[int]
    key: str
    name: str
    created_at: str
    updated_at: str
    type: Service.ServiceType
    icon: str
    editor_config: _any_pb2.Any
    def __init__(self, key: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., type: _Optional[_Union[Service.ServiceType, str]] = ..., icon: _Optional[str] = ..., editor_config: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ServicesRequest(_message.Message):
    __slots__ = ["company_id"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    def __init__(self, company_id: _Optional[str] = ...) -> None: ...

class ServicesResponse(_message.Message):
    __slots__ = ["services"]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    services: _containers.RepeatedCompositeFieldContainer[Service]
    def __init__(self, services: _Optional[_Iterable[_Union[Service, _Mapping]]] = ...) -> None: ...

class ServiceRequest(_message.Message):
    __slots__ = ["company_id", "key"]
    COMPANY_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    company_id: str
    key: str
    def __init__(self, company_id: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class ServiceResponse(_message.Message):
    __slots__ = ["service"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    service: Service
    def __init__(self, service: _Optional[_Union[Service, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import service_pb2 as service__pb2


class ConnectorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Services = channel.unary_unary(
                '/connector.service.ConnectorService/Services',
                request_serializer=service__pb2.ServicesRequest.SerializeToString,
                response_deserializer=service__pb2.ServicesResponse.FromString,
                )
        self.Service = channel.unary_unary(
                '/connector.service.ConnectorService/Service',
                request_serializer=service__pb2.ServiceRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceResponse.FromString,
                )


class ConnectorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Services(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Service(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Services': grpc.unary_unary_rpc_method_handler(
                    servicer.Services,
                    request_deserializer=service__pb2.ServicesRequest.FromString,
                    response_serializer=service__pb2.ServicesResponse.SerializeToString,
            ),
            'Service': grpc.unary_unary_rpc_method_handler(
                    servicer.Service,
                    request_deserializer=service__pb2.ServiceRequest.FromString,
                    response_serializer=service__pb2.ServiceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'connector.service.ConnectorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Services(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.service.ConnectorService/Services',
            service__pb2.ServicesRequest.SerializeToString,
            service__pb2.ServicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Service(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.service.ConnectorService/Service',
            service__pb2.ServiceRequest.SerializeToString,
            service__pb2.ServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
